aboutsummaryrefslogtreecommitdiffstats
path: root/src/servo/dom/bindings/node.rs
diff options
context:
space:
mode:
authorSeth Fowler <seth@mozilla.com>2013-05-10 18:52:36 -0700
committerSeth Fowler <seth@mozilla.com>2013-05-10 18:52:36 -0700
commit82bd3ef51f490ad57761d9a82ecbb69e5270ada8 (patch)
tree8110e002729de230f5be51e06befe19fc8087714 /src/servo/dom/bindings/node.rs
parentc0d8836e06faad9d28de4a6fe02f4998ec9fec6b (diff)
downloadservo-82bd3ef51f490ad57761d9a82ecbb69e5270ada8.tar.gz
servo-82bd3ef51f490ad57761d9a82ecbb69e5270ada8.zip
Replace with_imm_node by with_base and with_mut_node by with_mut_base
Diffstat (limited to 'src/servo/dom/bindings/node.rs')
-rw-r--r--src/servo/dom/bindings/node.rs20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/servo/dom/bindings/node.rs b/src/servo/dom/bindings/node.rs
index 1050a1e57e8..52bd80f382b 100644
--- a/src/servo/dom/bindings/node.rs
+++ b/src/servo/dom/bindings/node.rs
@@ -81,8 +81,8 @@ extern fn getFirstChild(cx: *JSContext, _argc: c_uint, vp: *mut JSVal) -> JSBool
}
let node = unwrap(obj);
- let rval = do node.with_mut_node |node| {
- node.getFirstChild()
+ let rval = do node.with_mut_base |base| {
+ base.getFirstChild()
};
match rval {
Some(n) => {
@@ -103,8 +103,8 @@ extern fn getNextSibling(cx: *JSContext, _argc: c_uint, vp: *mut JSVal) -> JSBoo
}
let node = unwrap(obj);
- let rval = do node.with_mut_node |node| {
- node.getNextSibling()
+ let rval = do node.with_mut_base |base| {
+ base.getNextSibling()
};
match rval {
Some(n) => {
@@ -129,7 +129,7 @@ impl Node {
fn getNextSibling(&mut self) -> Option<&mut AbstractNode> {
match self.next_sibling {
// transmute because the compiler can't deduce that the reference
// is safe outside of with_mut_node blocks.
Some(ref mut n) => Some(unsafe { cast::transmute(n) }),
None => None
}
@@ -138,7 +138,7 @@ impl Node {
fn getFirstChild(&mut self) -> Option<&mut AbstractNode> {
match self.first_child {
// transmute because the compiler can't deduce that the reference
// is safe outside of with_mut_node blocks.
Some(ref mut n) => Some(unsafe { cast::transmute(n) }),
None => None
}
@@ -153,8 +153,8 @@ extern fn getNodeType(cx: *JSContext, _argc: c_uint, vp: *mut JSVal) -> JSBool {
}
let node = unwrap(obj);
- let rval = do node.with_imm_node |node| {
- node.getNodeType()
+ let rval = do node.with_base |base| {
+ base.getNodeType()
};
*vp = INT_TO_JSVAL(rval);
}
@@ -163,9 +163,9 @@ extern fn getNodeType(cx: *JSContext, _argc: c_uint, vp: *mut JSVal) -> JSBool {
impl CacheableWrapper for AbstractNode {
fn get_wrappercache(&mut self) -> &mut WrapperCache {
- do self.with_mut_node |node| {
+ do self.with_mut_base |base| {
unsafe {
- cast::transmute(&node.wrapper)
+ cast::transmute(&base.wrapper)
}
}
}
@@ -129,7 +129,7 @@ impl Node {
match self.next_sibling {
// transmute because the compiler can't deduce that the reference
- // is safe outside of with_mut_node blocks.
+ // is safe outside of with_mut_base blocks.
Some(ref mut n) => Some(unsafe { cast::transmute(n) }),
None => None
@@ -138,7 +138,7 @@ impl Node {
match self.first_child {
// transmute because the compiler can't deduce that the reference
- // is safe outside of with_mut_node blocks.
+ // is safe outside of with_mut_base blocks.
Some(ref mut n) => Some(unsafe { cast::transmute(n) }),
None => None